==> libphidget22-1.0.0.20170906.tar.gz: libphidget22-1.0.0.20170906/src/class/temperaturesensor.c <==
/* Generated: Wed Jan 27 2016 14:22:18 GMT-0700 (Mountain Standard Time) */
/* Will not be regenerated. */

#include "phidgetbase.h"
#include "class/temperaturesensor.gen.h"
#include "class/temperaturesensor.gen.c"

static void
PhidgetTemperatureSensor_errorHandler(PhidgetChannelHandle phid, Phidget_ErrorEventCode code) {
	PhidgetTemperatureSensorHandle ch = (PhidgetTemperatureSensorHandle)phid;
	switch (code) {
	case EEPHIDGET_SATURATION:
		ch->temperature = PUNK_DBL;
		break;
	case EEPHIDGET_OUTOFRANGE:
		ch->temperature = PUNK_DBL;
		break;
	}
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_setStatus(PhidgetChannelHandle phid, BridgePacket *bp) {
	return (_setStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_getStatus(PhidgetChannelHandle phid, BridgePacket **bp) {
	return (_getStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_initAfterOpen(PhidgetChannelHandle phid) {
	return (_initAfterOpen(phid));
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_setDefaults(PhidgetChannelHandle phid) {
	return (_setDefaults(phid));
}

extern const int thermocouple_useful_range[5][2];

#include "types.gen.h"

static PhidgetReturnCode
PhidgetTemperatureSensor_bridgeInput(PhidgetChannelHandle phid, BridgePacket *bp) {
	PhidgetTemperatureSensorHandle ch;
	int type;

	ch = (PhidgetTemperatureSensorHandle)phid;

	/*
	 * Set the temperature to unknown if the RTD or thermocouple type is changed.
	 * For thermocouples, reset the max/min range based on thermocouple type.
	 */
	switch (bp->vpkt) {
	case BP_SETRTDTYPE:
		type = getBridgePacketInt32(bp, 0);
		switch (type) {
		case RTD_TYPE_PT100_3850:
		case RTD_TYPE_PT1000_3850:
		case RTD_TYPE_PT100_3920:
		case RTD_TYPE_PT1000_3920:
			break;
		default:
			return (EPHIDGET_INVALIDARG);
		}
		PhidgetRunLock(ch);
		ch->temperature = PUNK_DBL;
		PhidgetRunUnlock(ch);
		break;
	case BP_SETTHERMOCOUPLETYPE:
		type = getBridgePacketInt32(bp, 0);
		switch (type) {
		case THERMOCOUPLE_TYPE_J:
		case THERMOCOUPLE_TYPE_K:
		case THERMOCOUPLE_TYPE_E:
		case THERMOCOUPLE_TYPE_T:
			break;
		default:
			return (EPHIDGET_INVALIDARG);
		}

		PhidgetRunLock(ch);
		ch->temperature = PUNK_DBL;
		ch->minTemperature = thermocouple_useful_range[type][0];
		ch->maxTemperature = thermocouple_useful_range[type][1];
		PhidgetRunUnlock(ch);
		break;
	}
	return (_bridgeInput(phid, bp));
}

static void
PhidgetTemperatureSensor_fireInitialEvents(PhidgetChannelHandle phid) {
	_fireInitialEvents(phid);
}

==> libphidget22-1.0.0.20190107.tar.gz: libphidget22-1.0.0.20190107/src/class/temperaturesensor.c <==
/* Generated: Wed Jan 27 2016 14:22:18 GMT-0700 (Mountain Standard Time) */
/* Will not be regenerated. */

#include "phidgetbase.h"
#include "class/temperaturesensor.gen.h"
#include "class/temperaturesensor.gen.c"

static void
PhidgetTemperatureSensor_errorHandler(PhidgetChannelHandle phid, Phidget_ErrorEventCode code) {
	PhidgetTemperatureSensorHandle ch = (PhidgetTemperatureSensorHandle)phid;
	switch (code) {
	case EEPHIDGET_SATURATION:
		ch->temperature = PUNK_DBL;
		break;
	case EEPHIDGET_OUTOFRANGE:
		ch->temperature = PUNK_DBL;
		break;
	}
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_setStatus(PhidgetChannelHandle phid, BridgePacket *bp) {
	return (_setStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_getStatus(PhidgetChannelHandle phid, BridgePacket **bp) {
	return (_getStatus(phid, bp));
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_initAfterOpen(PhidgetChannelHandle phid) {
	return (_initAfterOpen(phid));
}

static PhidgetReturnCode CCONV
PhidgetTemperatureSensor_setDefaults(PhidgetChannelHandle phid) {
	return (_setDefaults(phid));
}

extern const int thermocouple_useful_range[5][2];

#include "types.gen.h"

static PhidgetReturnCode
PhidgetTemperatureSensor_bridgeInput(PhidgetChannelHandle phid, BridgePacket *bp) {
	PhidgetTemperatureSensorHandle ch;
	PhidgetReturnCode res;

	ch = (PhidgetTemperatureSensorHandle)phid;

	/*
	 * Set the temperature to unknown if the RTD or thermocouple type is changed.
	 * For thermocouples, reset the max/min range based on thermocouple type.
	 */
	switch (bp->vpkt) {
	case BP_SETRTDTYPE:
		res = _bridgeInput(phid, bp);
		if (res == EPHIDGET_OK) {
			PhidgetRunLock(ch);
			ch->temperature = PUNK_DBL;
			PhidgetRunUnlock(ch);
		}
		break;
	case BP_SETTHERMOCOUPLETYPE:
		res = _bridgeInput(phid, bp);
		if (res == EPHIDGET_OK) {
			PhidgetRunLock(ch);
			ch->temperature = PUNK_DBL;
			ch->minTemperature = thermocouple_useful_range[(PhidgetTemperatureSensor_ThermocoupleType)getBridgePacketInt32(bp, 0)][0];
			ch->maxTemperature = thermocouple_useful_range[(PhidgetTemperatureSensor_ThermocoupleType)getBridgePacketInt32(bp, 0)][1];
			PhidgetRunUnlock(ch);
		}
		break;
	default:
		res = _bridgeInput(phid, bp);
		break;
	}

	return (res);
}

static void
PhidgetTemperatureSensor_fireInitialEvents(PhidgetChannelHandle phid) {
	_fireInitialEvents(phid);
}
